@@ -1,12 +1,14 @@
+from __future__ import absolute_import
+from __future__ import print_function
 import logging
-from pprint import pprint
 import urllib
 
 import flask
-from flask.ext.script import Manager, Command, Option
+from flask_script import Manager, Command, Option
 
 from webgrid_ta.app import create_app
 import webgrid_ta.model as model
+from webgrid_ta.extensions import lazy_gettext as _
 from webgrid_ta.model.helpers import clear_db
 
 log = logging.getLogger(__name__)
@@ -17,21 +19,21 @@ class CreateDB(Command):
 
     option_list = (
         Option('--clear', default=False, dest='clear', action="store_true",
-               help='DROP all DB objects first'),
+               help=_('DROP all DB objects first')),
     )
 
     def run(self, clear):
         if clear:
             clear_db()
-            print '- db cleared'
+            print(_('- db cleared'))
 
         model.load_db()
-        print '- db loaded'
+        print(_('- db loaded'))
 
 
 manager = Manager(create_app)
 manager.add_option('-c', dest='config', default='Dev',
-                   help='flask configuration to use', required=False)
+                   help=_('flask configuration to use'), required=False)
 manager.add_command('create-db', CreateDB())
 
 
@@ -46,12 +48,15 @@ def list_routes(name='list-routes'):
     for line in sorted(output):
         print(line)
 
+
 @manager.command
 def serve():
     flask.current_app.run(debug=True)
 
+
 def script_entry():
     manager.run()
 
+
 if __name__ == "__main__":
     script_entry()
